#ifndef NT2_INCLUDE_FUNCTIONS_POPCNT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POPCNT_HPP_INCLUDED

#include <nt2/bitwise/include/functions/popcnt.hpp>

#endif
